Plot of total cell or nuclei number per sample grouped by another meta data variable.
Plot_Cells_per_Sample(
seurat_object,
sample_col = "orig.ident",
group.by = NULL,
colors_use = NULL,
dot_size = 1,
plot_title = "Cells/Nuclei per Sample",
y_axis_label = "Number of Cells",
x_axis_label = NULL,
legend_title = NULL,
x_lab_rotate = TRUE,
reorder = FALSE,
reorder_decreasing = FALSE,
plot_median = TRUE,
color_seed = 123
)Seurat object name.
Specify which column in meta.data specifies sample ID (i.e. orig.ident).
Column in meta.data slot to group results by (i.e. "Treatment").
List of colors or color palette to use.
size of the dots plotted if group.by is not NULL. Default is 1.
Plot title.
Label for y axis.
Label for x axis.
Label for plot legend.
logical. Whether to rotate the axes labels on the x-axis. Default is FALSE.
logical, if plotting by sample should x-axis be reordered according to number of cells, default is FALSE.
logical, if reorder = TRUE should points be ordered from fewest to
greatest number of cells (FALSE) or reverse (TRUE), default is FALSE.
logical, if plotting by sample should line be added showing median, default is TRUE.
random seed for the "varibow" palette shuffle if colors_use = NULL and number of
groups plotted is greater than 36. Default = 123.
A ggplot object
if (FALSE) {
# Plot cells per sample grouped by "Diagnosis"
Plot_Cells_per_Sample(seurat_object = obj, sample_col = "orig.ident", group.by = "Diagnosis")
# Plot cells per sample individually
Plot_Cells_per_Sample(seurat_object = obj, sample_col = "orig.ident", group.by = "orig.ident")
#' # Plot cells per sample individually and reorder x-axis by cell number
Plot_Cells_per_Sample(seurat_object = obj, sample_col = "orig.ident", group.by = "orig.ident",
order = TRUE)
}